==> e107-0.7.20.tbz: www/e107/e107_plugins/newsletter/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Steve Dunstan 2001-2002
|     http://e107.org
|     jalist@e107.org
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/newsletter/languages/English.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/

define("NLLAN_MENU_CAPTION", "Newsletter");

define("NLLAN_01", "Newsletter");
define("NLLAN_02", "Provides a quick and easy way to configure and send newsletters");
define("NLLAN_03", "Configure Newsletters");
define("NLLAN_04", "The newsletter plugin has been successfully installed. To configure, return to your main admin page and click on 'Newsletter' in the plugin section.");
define("NLLAN_05", "No newsletters defined yet");

define("NLLAN_06", "Name");
define("NLLAN_07", "Subscribers");
define("NLLAN_08", "Options");
define("NLLAN_09", "Are you sure you want to delete this newsletter?");
define("NLLAN_10", "Existing Newsletters");

define("NLLAN_11", "No newsletter issues yet");
define("NLLAN_12", "Issue");
define("NLLAN_13", "[ Parent ID ] Subject/Title");
define("NLLAN_14", "Mailed?");
define("NLLAN_15", "Options");
define("NLLAN_16", "yes");
define("NLLAN_17", "Not sent out - click to send");
define("NLLAN_18", "Are you sure you want to mail this issue to subscribers?");
define("NLLAN_19", "Are you sure you want to delete this newsletter issue?");
define("NLLAN_20", "Existing Issues");
define("NLLAN_21", "Title");
define("NLLAN_22", "Description");
define("NLLAN_23", "Header");
define("NLLAN_24", "Footer");
define("NLLAN_25", "Update Newsletter");
define("NLLAN_26", "Create Newsletter");
define("NLLAN_27", "Newsletter updated in database.");
define("NLLAN_28", "Newsletter defined and saved in database.");
define("NLLAN_29", "No newsletters defined yet.");
define("NLLAN_30", "Newsletter");
define("NLLAN_31", "Subject / Title");
define("NLLAN_32", "Issue Number");
define("NLLAN_33", "Text");
define("NLLAN_34", "Update Mailing");
define("NLLAN_35", "Create Mailing");
define("NLLAN_36", "Update Newsletter Issue");
define("NLLAN_37", "Create Newsletter Issue");
define("NLLAN_38", "Newsletter updated in database.");
define("NLLAN_39", "Newsletter issue saved in database - to send out, click the 'Release Issue' button in the Options menu.");
define("NLLAN_40", "Mailout completed - issue sent to ");

define("NLLAN_41", " subscriber(s).");
define("NLLAN_42", "Newsletter deleted.");
define("NLLAN_43", "Newsletter issue deleted.");

define("NLLAN_44", "Newsletter Front Page");
define("NLLAN_45", "Create Newsletter");
define("NLLAN_46", "Create mailing");
define("NLLAN_47", "Newsletter Options");

define("NLLAN_48", "you are subscribed to this newsletter - if you wish to unsubscribe please click the button below.");
define("NLLAN_49", "Are you sure you want to un-subscribe from this newsletter?");
define("NLLAN_50", "Click button to subscribe ( your subscription address is");
define("NLLAN_51", "Unsubscribe");
define("NLLAN_52", "Subscribe");
define("NLLAN_53", "Are you sure you want to subscribe to this newsletter?");

define("NLLAN_54", "Sending");

define("NLLAN_55", "ID");
define("NLLAN_56", "Newsletter ID not available");
define("NLLAN_57", "Return to previous page");
define("NLLAN_58", "Error");
define("NLLAN_59", "Name");
define("NLLAN_60", "Email");
define("NLLAN_61", "Actions");
define("NLLAN_62", "User is banned! (or not fully signed up)");
define("NLLAN_63", "Total subscribers");
define("NLLAN_64", "Return to Newsletter frontpage");
define("NLLAN_65", "Subscribers overview newsletter ID");

?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/newsletter/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Copyright (C) 2001-2002 Steve Dunstan (jalist@e107.org)
|     Copyright (C) 2008-2010 e107 Inc (e107.org)
|
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/newsletter/languages/English.php $
|     $Revision: 11678 $
|     $Id: English.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/

define("NLLAN_MENU_CAPTION", "Newsletter");

define("NLLAN_01", "Newsletter");
define("NLLAN_02", "Provides a quick and easy way to configure and send newsletters");
define("NLLAN_03", "Configure Newsletters");
define("NLLAN_04", "The newsletter plugin has been successfully installed. To configure, return to your main admin page and click on 'Newsletter' in the plugin section.");
define("NLLAN_05", "No newsletters defined yet");

define("NLLAN_06", "Name");
define("NLLAN_07", "Subscribers");
define("NLLAN_08", "Options");
define("NLLAN_09", "Are you sure you want to delete this newsletter?");
define("NLLAN_10", "Existing Newsletters");

define("NLLAN_11", "No newsletter issues yet");
define("NLLAN_12", "Issue");
define("NLLAN_13", "[ Parent ID ] Subject/Title");
define("NLLAN_14", "Mailed?");
define("NLLAN_15", "Options");
define("NLLAN_16", "yes");
define("NLLAN_17", "Not sent out - click to send");
define("NLLAN_18", "Are you sure you want to mail this issue to subscribers?");
define("NLLAN_19", "Are you sure you want to delete this newsletter issue?");
define("NLLAN_20", "Existing Issues");
define("NLLAN_21", "Title");
define("NLLAN_22", "Description");
define("NLLAN_23", "Header");
define("NLLAN_24", "Footer");
define("NLLAN_25", "Update Newsletter");
define("NLLAN_26", "Create Newsletter");
define("NLLAN_27", "Newsletter updated in database.");
define("NLLAN_28", "Newsletter defined and saved in database.");
define("NLLAN_29", "No newsletters defined yet.");
define("NLLAN_30", "Newsletter");
define("NLLAN_31", "Subject / Title");
define("NLLAN_32", "Issue Number");
define("NLLAN_33", "Text");
define("NLLAN_34", "Update Mailing");
define("NLLAN_35", "Create Mailing");
define("NLLAN_36", "Update Newsletter Issue");
define("NLLAN_37", "Create Newsletter Issue");
define("NLLAN_38", "Newsletter updated in database.");
define("NLLAN_39", "Newsletter issue saved in database - to send out, click the 'Release Issue' button in the Options menu.");
define("NLLAN_40", "Mailout completed - issue sent to ");

define("NLLAN_41", " subscriber(s).");
define("NLLAN_42", "Newsletter deleted.");
define("NLLAN_43", "Newsletter issue deleted.");

define("NLLAN_44", "Newsletter Front Page");
define("NLLAN_45", "Create Newsletter");
define("NLLAN_46", "Create mailing");
define("NLLAN_47", "Newsletter Options");

define("NLLAN_48", "you are subscribed to this newsletter - if you wish to unsubscribe please click the button below.");
define("NLLAN_49", "Are you sure you want to un-subscribe from this newsletter?");
define("NLLAN_50", "Click button to subscribe ( your subscription address is");
define("NLLAN_51", "Unsubscribe");
define("NLLAN_52", "Subscribe");
define("NLLAN_53", "Are you sure you want to subscribe to this newsletter?");

define("NLLAN_54", "Sending");

define("NLLAN_55", "ID");
define("NLLAN_56", "Newsletter ID not available");
define("NLLAN_57", "Return to previous page");
define("NLLAN_58", "Error");
define("NLLAN_59", "Name");
define("NLLAN_60", "Email");
define("NLLAN_61", "Actions");
define("NLLAN_62", "User is banned! (or not fully signed up)");
define("NLLAN_63", "Total subscribers");
define("NLLAN_64", "Return to Newsletter frontpage");
define("NLLAN_65", "Subscribers overview newsletter ID");

?>
